@@ -138,10 +138,11 @@ class VolumeTest(base.EC2TestCase):
         self.cancelResourceCleanUp(res_clean)
         self.get_volume_waiter().wait_delete(volume_id)
 
-    @testtools.skipUnless(CONF.aws.image_id, "image id is not defined")
+    @testtools.skipUnless(CONF.aws.ebs_image_id, "ebs image id is not defined")
     def test_attach_detach_volume(self):
         clean_dict = {}
-        instance_id = self.run_instance(clean_dict=clean_dict)
+        instance_id = self.run_instance(ImageId=CONF.aws.ebs_image_id,
+                                        clean_dict=clean_dict)
         clean_i = clean_dict['instance']
 
         kwargs = {
@@ -189,6 +190,11 @@ class VolumeTest(base.EC2TestCase):
         self.assertIn('DeviceName', bdms[0])
         self.assertIn('Ebs', bdms[0])
 
+        # stop instance to prevent 'busy' state of detached volume
+        data = self.client.stop_instances(InstanceIds=[instance_id])
+        self.get_instance_waiter().wait_available(instance_id,
+                                                  final_set=('stopped'))
+
         self.client.detach_volume(VolumeId=volume_id)
         self.get_volume_attachment_waiter().wait_delete(volume_id)
         self.cancelResourceCleanUp(clean_vi)
@@ -207,10 +213,11 @@ class VolumeTest(base.EC2TestCase):
         self.cancelResourceCleanUp(clean_i)
         self.get_instance_waiter().wait_delete(instance_id)
 
-    @testtools.skipUnless(CONF.aws.image_id, "image id is not defined")
+    @testtools.skipUnless(CONF.aws.ebs_image_id, "EBS image id is not defined")
     def test_attaching_stage(self):
         clean_dict = {}
-        instance_id = self.run_instance(clean_dict=clean_dict)
+        instance_id = self.run_instance(ImageId=CONF.aws.ebs_image_id,
+                                        clean_dict=clean_dict)
         clean_i = clean_dict['instance']
 
         data = self.client.create_volume(
@@ -244,6 +251,11 @@ class VolumeTest(base.EC2TestCase):
         clean_i = self.addResourceCleanUp(self.client.terminate_instances,
                                           InstanceIds=[instance_id])
 
+        # stop instance to prevent 'busy' state of detached volume
+        data = self.client.stop_instances(InstanceIds=[instance_id])
+        self.get_instance_waiter().wait_available(instance_id,
+                                                  final_set=('stopped'))
+
         self.client.detach_volume(VolumeId=volume_id)
         self.get_volume_attachment_waiter().wait_delete(volume_id)
         self.cancelResourceCleanUp(clean_vi)
@@ -258,9 +270,9 @@ class VolumeTest(base.EC2TestCase):
 
     @testtools.skipUnless(CONF.aws.run_incompatible_tests,
                           "Volume statuses are not implemented")
-    @testtools.skipUnless(CONF.aws.image_id, "image id is not defined")
+    @testtools.skipUnless(CONF.aws.ebs_image_id, "EBS image id is not defined")
     def test_delete_detach_attached_volume(self):
-        instance_id = self.run_instance()
+        instance_id = self.run_instance(ImageId=CONF.aws.ebs_image_id)
 
         kwargs = {
             'Size': 1,
@@ -296,6 +308,11 @@ class VolumeTest(base.EC2TestCase):
                           self.client.delete_volume,
                           VolumeId=volume_id)
 
+        # stop instance to prevent 'busy' state of detached volume
+        data = self.client.stop_instances(InstanceIds=[instance_id])
+        self.get_instance_waiter().wait_available(instance_id,
+                                                  final_set=('stopped'))
+
         self.client.detach_volume(VolumeId=volume_id)
         self.cancelResourceCleanUp(clean_vi)
         self.get_volume_attachment_waiter().wait_delete(volume_id)
